Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorLars Vogel2019-11-11 10:48:52 +0000
committerLars Vogel2019-11-12 05:55:20 +0000
commit3b0243f3a75600c950b60cfc5b17449e5b22c0a2 (patch)
tree579216fdf3a413134f9a86d4a5d46117a6a66458
parentd798f1df59f3682aa84ddc8ed6a18d013f7f6e7b (diff)
downloadeclipse.platform.debug-3b0243f3a75600c950b60cfc5b17449e5b22c0a2.tar.gz
eclipse.platform.debug-3b0243f3a75600c950b60cfc5b17449e5b22c0a2.tar.xz
eclipse.platform.debug-3b0243f3a75600c950b60cfc5b17449e5b22c0a2.zip
Use a more telling parameter name in DebugUIPlugin#getImageDescriptor
Change-Id: Ib062a2df9dba1d1ae494cc7d3e5c37ea9c79f7de Signed-off-by: Lars Vogel <Lars.Vogel@vogella.com>
-rw-r--r--org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/DebugUIPlugin.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/DebugUIPlugin.java b/org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/DebugUIPlugin.java
index 2fb343682..29cf21f93 100644
--- a/org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/DebugUIPlugin.java
+++ b/org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/DebugUIPlugin.java
@@ -1359,13 +1359,13 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener,
* Returns an image descriptor for the icon referenced by the given path
* and contributor name, or <code>null</code> if none.
*
* @param name the name of the contributor
* @param path the path of the icon (from the configuration element)
* @return image descriptor or <code>null</code>
* @since 3.3
*/
- public static ImageDescriptor getImageDescriptor(String name, String path) {
- Bundle bundle = Platform.getBundle(name);
+ public static ImageDescriptor getImageDescriptor(String bundleName, String path) {
+ Bundle bundle = Platform.getBundle(bundleName);
if (path != null) {
URL iconURL = FileLocator.find(bundle , new Path(path), null);
if (iconURL != null) {
@@ -1359,13 +1359,13 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener,
* and contributor name, or <code>null</code> if none.
*
- * @param name the name of the contributor
+ * @param bundleName the name of the contributor
* @param path the path of the icon (from the configuration element)
* @return image descriptor or <code>null</code>

Back to the top